@@ -3,6 +3,7 @@ package cli
 import (
 	"fmt"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/cli/image"
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/prompt"
@@ -48,10 +49,10 @@ Exports the config to an image file ~/mytheme.png.
 Exports the config to an image file using customized output settings.`,
 	Args: cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
-		cfg, _ := config.Load(configFlag, false)
+		cfg := config.Load(configFlag, false)
 
 		flags := &runtime.Flags{
-			Config:        cfg.Source,
+			ConfigPath:    cfg.Source,
 			Shell:         shell.GENERIC,
 			TerminalWidth: 120,
 		}
@@ -59,11 +60,13 @@ Exports the config to an image file using customized output settings.`,
 		env := &runtime.Terminal{}
 		env.Init(flags)
 
+		cache.Init(shellName, false)
+
 		template.Init(env, cfg.Var, cfg.Maps)
 
 		defer func() {
 			template.SaveCache()
-			env.Close()
+			cache.Close()
 		}()
 
 		// set sane defaults for things we don't print
