@@ -5,7 +5,6 @@ import (
 
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
-	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 
 	"github.com/spf13/cobra"
 )
@@ -40,16 +39,15 @@ Migrates the ~/myconfig.omp.json config file to TOML and writes the result to yo
 A backup of the current config can be found at ~/myconfig.omp.json.bak.`,
 	Args: cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
-		cfg, _ := config.Load(configFlag, shell.GENERIC, true)
+		cfg := config.Load(configFlag, true)
 
 		flags := &runtime.Flags{
-			Config:  cfg.Source,
-			Migrate: true,
+			ConfigPath: cfg.Source,
+			Migrate:    true,
 		}
 
 		env := &runtime.Terminal{}
 		env.Init(flags)
-		defer env.Close()
 
 		if write {
 			cfg.BackupAndMigrate()
