@@ -134,12 +134,10 @@ type Renderer struct {
 }
 
 func (ir *Renderer) Init(env runtime.Environment) error {
-	ir.setOutputPath(env.Flags().Config)
+	ir.setOutputPath(env.Flags().ConfigPath)
 
 	ir.cleanContent()
 
-	font_.SetCache(env.Cache())
-
 	if err := ir.loadFonts(); err != nil {
 		return err
 	}
