@@ -4,8 +4,8 @@ import (
 	"fmt"
 	"path/filepath"
 	"strings"
-	"time"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
@@ -70,37 +70,40 @@ See the documentation to initialize your shell: https://ohmyposh.dev/docs/instal
 }
 
 func runInit(sh, command string) {
-	var startTime time.Time
-
 	if debug {
-		startTime = time.Now()
 		log.Enable(plain)
 	}
 
-	cfg, hash := config.Load(configFlag, sh, false)
+	cfg := config.Load(configFlag, false)
 
 	flags := &runtime.Flags{
-		Shell:     sh,
-		Config:    cfg.Source,
-		Strict:    strict,
-		Debug:     debug,
-		SaveCache: true,
-		Init:      true,
-		Eval:      eval,
+		Shell:      sh,
+		ConfigPath: cfg.Source,
+		ConfigHash: cfg.Base64(),
+		Strict:     strict,
+		Debug:      debug,
+		Init:       true,
+		Eval:       eval,
+		Plain:      plain,
 	}
 
 	env := &runtime.Terminal{}
 	env.Init(flags)
 
+	cache.Init(sh, true)
+
 	template.Init(env, cfg.Var, cfg.Maps)
 
 	defer func() {
+		cfg.Store()
 		template.SaveCache()
-		env.Close()
+		if err := cache.Clear(false, shell.InitScriptName(env.Flags())); err != nil {
+			log.Error(err)
+		}
+		cache.Close()
 	}()
 
 	feats := cfg.Features(env)
-	flags.ConfigHash = fmt.Sprintf("%s.%s", hash, feats.Hash())
 
 	var output string
 
@@ -113,12 +116,12 @@ func runInit(sh, command string) {
 
 	if !debug {
 		configDSC := config.DSC()
-		configDSC.Load(env.Cache())
+		configDSC.Load()
 		configDSC.Add(configFlag)
 		configDSC.Save()
 
 		shellDSC := shell.DSC()
-		shellDSC.Load(env.Cache())
+		shellDSC.Load()
 		shellDSC.Add(&shell.Shell{
 			Command: command,
 			Name:    sh,
