@@ -6,6 +6,7 @@ var (
 )
 
 type Dart struct {
+	Dummy struct{}
 	language
 }
 
@@ -17,6 +18,11 @@ func (d *Dart) Enabled() bool {
 	d.extensions = dartExtensions
 	d.folders = dartFolders
 	d.commands = []*cmd{
+		{
+			executable: "fvm",
+			args:       []string{"dart", "--version"},
+			regex:      `Dart SDK version: (?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+)))`,
+		},
 		{
 			executable: "dart",
 			args:       []string{"--version"},
