@@ -8,6 +8,7 @@ import (
 )
 
 type Wakatime struct {
+	Dummy struct{}
 	base
 
 	wtData
@@ -56,9 +57,5 @@ func (w *Wakatime) setAPIData() error {
 
 func (w *Wakatime) getURL() (string, error) {
 	url := w.props.GetString(URL, "")
-	tmpl := &template.Text{
-		Template: url,
-		Context:  w,
-	}
-	return tmpl.Render()
+	return template.Render(url, w)
 }
