@@ -1,7 +1,6 @@
 package template
 
 import (
-	"encoding/json"
 	"strconv"
 	"strings"
 	"time"
@@ -18,10 +17,10 @@ var (
 	Cache *cache.Template
 )
 
-func loadCache(vars maps.Simple, aliases *maps.Config) {
+func loadCache(vars maps.Simple[any], aliases *maps.Config) {
 	if !env.Flags().IsPrimary {
 		// Load the template cache for a non-primary prompt before rendering any templates.
-		if OK := restoreCache(env); OK {
+		if OK := restoreCache(); OK {
 			return
 		}
 	}
@@ -33,7 +32,7 @@ func loadCache(vars maps.Simple, aliases *maps.Config) {
 	Cache.ShellVersion = env.Flags().ShellVersion
 	Cache.Code, _ = env.StatusCodes()
 	Cache.WSL = env.IsWsl()
-	Cache.Segments = maps.NewConcurrent()
+	Cache.Segments = maps.NewConcurrent[any]()
 	Cache.PromptCount = env.Flags().PromptCount
 	Cache.Var = make(map[string]any)
 	Cache.Jobs = env.Flags().JobCount
@@ -76,22 +75,15 @@ func loadCache(vars maps.Simple, aliases *maps.Config) {
 	}
 }
 
-func restoreCache(env runtime.Environment) bool {
+func restoreCache() bool {
 	defer log.Trace(time.Now())
 
-	val, OK := env.Session().Get(cache.TEMPLATECACHE)
+	val, OK := cache.Get[*cache.SimpleTemplate](cache.Session, cache.TEMPLATECACHE)
 	if !OK {
 		return false
 	}
 
-	var tmplCache cache.Template
-	err := json.Unmarshal([]byte(val), &tmplCache)
-	if err != nil {
-		log.Error(err)
-		return false
-	}
-
-	Cache = &tmplCache
+	Cache.SimpleTemplate = *val
 	Cache.Segments = Cache.SegmentsCache.ToConcurrent()
 
 	return true
@@ -107,8 +99,5 @@ func SaveCache() {
 
 	Cache.SegmentsCache = Cache.Segments.ToSimple()
 
-	templateCache, err := json.Marshal(Cache)
-	if err == nil {
-		env.Session().Set(cache.TEMPLATECACHE, string(templateCache), cache.ONEDAY)
-	}
+	cache.Set(cache.Session, cache.TEMPLATECACHE, &Cache.SimpleTemplate, cache.ONEDAY)
 }
